@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: gc.c,v 1.10 1999/11/22 18:26:24 bazsi Exp $
+ * $Id: gc.c,v 1.12 2000/06/23 12:55:51 bazsi Exp $
  *
  ***************************************************************************/
 
@@ -63,6 +63,7 @@ static void sanity_check_object_list(void)
  * for keeping track of the marked but not yet traced objects. */
 static void gc_mark(struct ol_object *o)
 {
+  static int depth = 0;
   if (!o)
     return;
   
@@ -84,15 +85,17 @@ static void gc_mark(struct ol_object *o)
 	struct ol_class *class;
 
 #if 0
-	debug("gc_mark: Marking object of class '%z'\n",
-	      o->isa ? o->isa->name : "UNKNOWN");
+	debug("gc_mark: Marking object of class '%z' (%i)\n",
+	      o->isa ? o->isa->name : "UNKNOWN", depth);
 #endif
 
+        depth++;
 	for (class = o->isa; class; class = class->super_class)
 	  {
 	    if (class->mark_instance)
 	      MARK_INSTANCE(class, o, gc_mark);
 	  }
+        depth--;
       }
       break;
     default:
