@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.21 2000/06/23 12:55:51 bazsi Exp $ */
+ * $Id: io.c,v 1.22 2000/09/01 10:10:08 bazsi Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -97,11 +97,9 @@ int io_iter(struct io_backend *b)
 	int timeout = -1;
 	time_t now = time(NULL);
 	
-	nfds = 0;
 	
 	{
-		/* Prepare fd:s. This fase calls the prepare-methods, also 
-closes
+		/* Prepare fd:s. This fase calls the prepare-methods, also  closes
 		 * and unlinks any fd:s that should be closed, and also counts how
 		 * many fd:s there are. */
 		
@@ -140,7 +138,6 @@ closes
 				*fd_p = fd->next;
 				continue;
 			}
-			nfds++;
 			fd_p = &fd->next;
 		}
 		
@@ -157,6 +154,15 @@ closes
 			}
 		}
 	}
+	nfds = 0;
+
+	{
+		struct nonblocking_fd *fd;
+
+		for(fd = b->files; fd; fd = fd->next) {
+			nfds++;
+		}
+	}
 
 	if (nfds) {
 		int all_events = 0;
