@@ -18,7 +18,7 @@
  *
  * Inspired by nsyslog, originally written by Darren Reed.
  *
- * $Id: pkt_buffer.c,v 1.8 1999/08/31 20:57:35 bazsi Exp $
+ * $Id: pkt_buffer.c,v 1.9 2000/02/04 19:02:04 bazsi Exp $
  *
  ***************************************************************************/
  
@@ -64,8 +64,10 @@ static int do_write_str(struct abstract_write *c, struct ol_string *string)
 {
 	CAST(pkt_buffer, self, c);
 	
-	if (self->super.closed)
+	if (self->super.closed) {
+		ol_string_free(string);
 		return ST_FAIL | ST_CLOSE;
+	}
 	if (self->queue_size == self->queue_max) {
 		/* fifo full */
 		ol_string_free(string);
@@ -107,6 +109,9 @@ static int do_flush(struct abstract_buffer *c, struct abstract_write *w)
 				ol_string_free(s);
 				break;
 			}
+			else {
+				break;
+			}
 		}
 		else {
 			verbose("pkt_buffer::do_flush(): Error flushing data\n");
